  #  Num2Word
  
  This module convert any number/digit to word
  For e.g. if you pass a number '98498' then,
  it will return 'Ninety Eight Thousand Four Hundred Ninety Eight'

## Installation
  Run the following command to install:
  ```pip install num2word```

## Usage
  ```Import word from num2word
  # Import word from num2word
   from num2word import word
   
   # Generate 'Nine Thousand eighty four'
   word('9284') or word(9284)

   #other examples
   <!-- you can use any bigger number -->
   a = 33221884729877832
   print(word(a)) /*It will print the output*/
   b = '99320489432099000982409203'
   b = word(b)
   <print(b)>/* will print out the the expected output */

  ```

